public_market_from_sec_key

Function public_market_from_sec_key 

pub fn public_market_from_sec_key(sec_key: &str) -> Option<i32>
Extract the public QotMarket prefix from a gateway/cache sec_key.

The canonical key format is "{market}_{code}". The code part is allowed to contain additional underscores because only the first separator belongs to the key envelope.